==> kubernetes-model-core-5.1.1-sources.jar: io/fabric8/kubernetes/api/model/KubernetesListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KubernetesListBuilder extends KubernetesListFluentImpl<KubernetesListBuilder> implements VisitableBuilder<KubernetesList,KubernetesListBuilder> {

    KubernetesListFluent<?> fluent;
    Boolean validationEnabled;

    public KubernetesListBuilder() {
        this(true);
    }

    public KubernetesListBuilder(Boolean validationEnabled) {
        this(new KubernetesList(), validationEnabled);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent) {
        this(fluent, true);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new KubernetesList(), validationEnabled);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent,KubernetesList instance) {
        this(fluent, instance, true);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent,KubernetesList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public KubernetesListBuilder(KubernetesList instance) {
        this(instance,true);
    }

    public KubernetesListBuilder(KubernetesList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public KubernetesList build() {
        KubernetesList buildable = new KubernetesList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KubernetesListBuilder that = (KubernetesListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/KubernetesListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KubernetesListBuilder extends KubernetesListFluentImpl<KubernetesListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<KubernetesList,KubernetesListBuilder> {

    KubernetesListFluent<?> fluent;
    Boolean validationEnabled;

    public KubernetesListBuilder() {
        this(true);
    }

    public KubernetesListBuilder(Boolean validationEnabled) {
        this(new KubernetesList(), validationEnabled);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent) {
        this(fluent, true);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new KubernetesList(), validationEnabled);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent,KubernetesList instance) {
        this(fluent, instance, true);
    }

    public KubernetesListBuilder(KubernetesListFluent<?> fluent,KubernetesList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public KubernetesListBuilder(KubernetesList instance) {
        this(instance,true);
    }

    public KubernetesListBuilder(KubernetesList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public KubernetesList build() {
        KubernetesList buildable = new KubernetesList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KubernetesListBuilder that = (KubernetesListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
